@@ -8,7 +8,7 @@
 #
 #
 #
-# reverse(''), March 2005, John McNamara, jmcnamara@cpan.org
+# reverse ('(c)'), March 2005, John McNamara, jmcnamara@cpan.org
 #
 
 use strict;
@@ -41,6 +41,7 @@ my $worksheet = $workbook->add_worksheet( $sheet . '1' );
 $worksheet->set_column( 'A:A', 18 );
 $worksheet->write( 'A1', $str );
 
+$workbook->close();
 
 __END__
 
